package temportalist.origin.api.common.block

import net.minecraft.block.Block
import net.minecraft.block.material.{MapColor, Material}
import net.minecraft.item.ItemBlock
import net.minecraftforge.fml.common.registry.GameRegistry
import temportalist.origin.api.common.IModDetails

/**
  * A basic wrapping class for blocks. Registers Blocks and ItemBlocks for you.
  *
  * @param mod The mod this block belongs to
  * @param name The name. Will use [[Class#getClass#getSimpleName]] if null
  * @param material The material, [[net.minecraft.block.material.Material.GROUND]] by default
  * @param mapColor The map color, [[Material.GROUND#getMaterialMapColor]] by default
  * @param hasItemBlock Whether this block should have an item block, true by default
  *
  * Created by TheTemportalist on 4/9/2016.
  * @author TheTemportalist
  */
class BlockBase(
		mod: IModDetails,
		var name: String = null,
		material: Material = Material.GROUND, mapColor: MapColor = null,
		hasItemBlock: Boolean = true
) extends Block(
	material,
	if (mapColor == null) material.getMaterialMapColor else mapColor
) {

	if (this.name == null) this.name = this.getClass.getSimpleName
	this.setRegistryName(this.mod.getModId, this.name)
	this.setUnlocalizedName(this.mod.getModId + ":" + this.name)
	GameRegistry.register(this)
	if (hasItemBlock)
		GameRegistry.register(this.createItemBlock().setRegistryName(this.getRegistryName))

	/**
	  * Create the ItemBlock instance. Called on initialization ONLY if [[hasItemBlock]] is true.
	  * @return the ItemBlock instance, a generic ItemBlock by default
	  */
	def createItemBlock(): ItemBlock = new ItemBlock(this)

}
